==> nextcloud-30.0.10.tgz: nextcloud/apps/viewer/l10n/sv.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visare",
    "Simple file viewer with slideshow for media" : "Enkel filvisare med bildspel för media",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Visa dina senaste semesterbilder och videor som i filmerna, visa en glimt av din senaste bok direkt från Nextcloud, välj bästa GIF i din samling tack vare den direkta förhandsgranskningen av dina favoritfiler och mycket mer!",
    "Your browser does not support audio." : "Din webbläsare har inte stöd för ljud.",
    "Error loading {name}" : "Fel vid inläsning av {name}",
    "Image saved" : "Bild sparad",
    "Error saving image" : "Det gick inte att spara bilden",
    "Unsaved changes" : "Ej sparade ändringar",
    "Drop changes" : "Släng ändringar",
    "Play the live photo" : "Spela upp livefotot",
    "LIVE" : "LIVE",
    "Your browser does not support videos." : "Din webbläsare har inte stöd för video.",
    "This file no longer exists" : "Den här filen finns inte längre",
    "There is no plugin available to display this file type" : "Det finns inget tillägg tillgängligt för att visa denna filtyp",
    "Edit" : "Ändra",
    "Exit full screen" : "Avsluta fullskärm",
    "Full screen" : "Fullskärm",
    "Open sidebar" : "Öppna sidofältet",
    "Download" : "Ladda ner",
    "Delete" : "Ta bort",
    "View" : "Visa",
    "Name" : "Namn",
    "Save" : "Spara",
    "Save as" : "Spara som",
    "Back" : "Tillbaka",
    "Loading …" : "Läser in …",
    "Reset" : "Återställ",
    "All changes will be lost." : "Alla ändringar kommer att gå förlorade.",
    "Are you sure you want to continue?" : "Är du säker på att du vill fortsätta?",
    "Cancel" : "Avbryt",
    "Apply" : "Tillämpa",
    "Warning" : "Varning",
    "Confirm" : "Bekräfta",
    "Discard changes" : "Släng ändringar",
    "Undo" : "Ångra",
    "Redo" : "Gör om",
    "Show original image" : "Visa originalbilden",
    "Zoom in" : "Zooma in",
    "Zoom out" : "Zooma ut",
    "Toggle zoom menu" : "Växla zoom-meny",
    "Adjust" : "Justera",
    "Fine-tune" : "Finjustera",
    "Filters" : "Filter",
    "Watermark" : "Vattenstämpel",
    "Draw" : "Rita",
    "Resize" : "Ändra storlek",
    "Image name" : "Bildens namn",
    "Invalid image." : "Ogiltig bild.",
    "Error while uploading the image." : "Det gick inte att ladda upp bilden.",
    "are not images" : "är inte bilder",
    "is not an image" : "är inte en bild",
    "to be uploaded" : "ska laddas upp",
    "Crop" : "Beskär",
    "Original" : "Orginal",
    "Custom" : "Anpassad",
    "Square" : "Fyrkant",
    "Landscape" : "Landskap",
    "Portrait" : "Porträtt",
    "Ellipse" : "Ellips",
    "Classic TV" : "Klassisk TV",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Pil",
    "Blur" : "Suddig",
    "Brightness" : "Ljusstyrka",
    "Contrast" : "Kontrast",
    "Un-flip X" : "Gör om vändning X",
    "Flip X" : "Vänd X",
    "Un-flip Y" : "Gör om vändning Y",
    "Flip Y" : "Vänd Y",
    "HSV" : "HSV",
    "Hue" : "Nyans",
    "Saturation" : "Mättnad",
    "Value" : "Värde",
    "Image" : "Bild",
    "Importing …" : "Importerar ...",
    "+ Add image" : "+ Lägg till bild",
    "Upload image" : "Ladda upp bild",
    "From gallery" : "Från galleri",
    "Line" : "Rad",
    "Pen" : "Penna",
    "Polygon" : "Polygon",
    "Sides" : "Sidor",
    "Rectangle" : "Rektangel",
    "Corner Radius" : "Hörnradie",
    "Width in pixels" : "Bredd i pixlar",
    "Height in pixels" : "Höjd i pixlar",
    "Toggle ratio lock" : "Växla låst bildförhållande",
    "Reset to original image size" : "Återställ till originalbildstorlek",
    "Rotate" : "Rotera",
    "Text" : "Text",
    "Text spacing" : "Textavstånd",
    "Text alignment" : "Textjustering",
    "Font family" : "Typsnittsfamilj",
    "Size" : "Storlek",
    "Letter spacing" : "Teckenavstånd",
    "Line height" : "Radavstånd",
    "Warmth" : "Värme",
    "+ Add watermark" : "+ Lägg till vattenstämpel",
    "+ Add text watermark" : "+ Lägg till vattenstämpel text",
    "Choose watermark type" : "Välj typ av vattenstämpel",
    "Upload watermark" : "Ladda upp vattenstämpel",
    "Add as text" : "Lägg till som text",
    "Padding" : "Utfyllnad",
    "Paddings" : "Utfyllnader",
    "Shadow" : "Skugga",
    "Horizontal" : "Horisontell",
    "Vertical" : "Vertikal",
    "Opacity" : "Opacitet",
    "Transparency" : "Transparens",
    "Position" : "Position",
    "Stroke" : "Penseldrag",
    "Save image as" : "Spara bild som",
    "Extension" : "Tillägg",
    "Format" : "Format",
    "Name is required." : "Namn är obligatoriskt.",
    "Quality" : "Kvalitet",
    "Saved image size (width x height)" : "Sparad bildstorlek (bredd x höjd)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Observera att det valda beskärningsområdet är lägre än den tillämpade storleksändringen, vilket kan orsaka kvalitetsförsämring",
    "Actual size (100%)" : "Faktisk storlek (100 %)",
    "Fit size" : "Passande storlek",
    "Select image to add …" : "Välj bild att lägga till ...",
    "Failed to load image." : "Det gick inte att ladda bilden.",
    "Menu" : "Meny",
    "Width" : "Bredd",
    "Height" : "Höjd",
    "No preview available for this crop item" : "Ingen förhandsgranskning tillgänglig för detta beskärningsobjekt"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.10.tgz: nextcloud/apps/viewer/l10n/sv.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visare",
    "Simple file viewer with slideshow for media" : "Enkel filvisare med bildspel för media",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Visa dina senaste semesterbilder och videor som i filmerna, visa en glimt av din senaste bok direkt från Nextcloud, välj bästa GIF i din samling tack vare den direkta förhandsgranskningen av dina favoritfiler och mycket mer!",
    "Your browser does not support audio." : "Din webbläsare har inte stöd för ljud.",
    "Error loading {name}" : "Fel vid inläsning av {name}",
    "You are about to overwrite the original file. Are you sure you want to continue?" : "Du är på väg att skriva över originalfilen. Är du säker på att du vill fortsätta?",
    "A file with this name already exists. Do you want to overwrite it?" : "En fil med det här namnet finns redan. Vill du skriva över den?",
    "Confirm overwrite" : "Bekräfta överskrivning",
    "Cancel" : "Avbryt",
    "Overwrite" : "Skriv över",
    "An error occurred while trying to confirm the file overwrite." : "Ett fel uppstod vid försök att bekräfta överskrivningen av filen.",
    "Image saved" : "Bild sparad",
    "Error saving image" : "Det gick inte att spara bilden",
    "Play the live photo" : "Spela upp livefotot",
    "LIVE" : "LIVE",
    "Your browser does not support videos." : "Din webbläsare har inte stöd för video.",
    "This file no longer exists" : "Den här filen finns inte längre",
    "There is no plugin available to display this file type" : "Det finns inget tillägg tillgängligt för att visa denna filtyp",
    "Edit" : "Ändra",
    "Exit full screen" : "Avsluta fullskärm",
    "Full screen" : "Fullskärm",
    "Open sidebar" : "Öppna sidofältet",
    "Download" : "Ladda ner",
    "Delete" : "Ta bort",
    "View" : "Visa",
    "Name" : "Namn",
    "Save" : "Spara",
    "Save as" : "Spara som",
    "Back" : "Tillbaka",
    "Loading …" : "Läser in …",
    "Reset" : "Återställ",
    "All changes will be lost." : "Alla ändringar kommer att gå förlorade.",
    "Are you sure you want to continue?" : "Är du säker på att du vill fortsätta?",
    "Apply" : "Tillämpa",
    "Warning" : "Varning",
    "Confirm" : "Bekräfta",
    "Discard changes" : "Släng ändringar",
    "Undo" : "Ångra",
    "Redo" : "Gör om",
    "Show original image" : "Visa originalbilden",
    "Zoom in" : "Zooma in",
    "Zoom out" : "Zooma ut",
    "Toggle zoom menu" : "Växla zoom-meny",
    "Adjust" : "Justera",
    "Fine-tune" : "Finjustera",
    "Filters" : "Filter",
    "Watermark" : "Vattenstämpel",
    "Draw" : "Rita",
    "Resize" : "Ändra storlek",
    "Image name" : "Bildens namn",
    "Invalid image." : "Ogiltig bild.",
    "Error while uploading the image." : "Det gick inte att ladda upp bilden.",
    "are not images" : "är inte bilder",
    "is not an image" : "är inte en bild",
    "to be uploaded" : "ska laddas upp",
    "Crop" : "Beskär",
    "Original" : "Orginal",
    "Custom" : "Anpassad",
    "Square" : "Fyrkant",
    "Landscape" : "Landskap",
    "Portrait" : "Porträtt",
    "Ellipse" : "Ellips",
    "Classic TV" : "Klassisk TV",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Pil",
    "Blur" : "Suddig",
    "Brightness" : "Ljusstyrka",
    "Contrast" : "Kontrast",
    "Un-flip X" : "Gör om vändning X",
    "Flip X" : "Vänd X",
    "Un-flip Y" : "Gör om vändning Y",
    "Flip Y" : "Vänd Y",
    "HSV" : "HSV",
    "Hue" : "Nyans",
    "Saturation" : "Mättnad",
    "Value" : "Värde",
    "Image" : "Bild",
    "Importing …" : "Importerar ...",
    "+ Add image" : "+ Lägg till bild",
    "Upload image" : "Ladda upp bild",
    "From gallery" : "Från galleri",
    "Line" : "Rad",
    "Pen" : "Penna",
    "Polygon" : "Polygon",
    "Sides" : "Sidor",
    "Rectangle" : "Rektangel",
    "Corner Radius" : "Hörnradie",
    "Width in pixels" : "Bredd i pixlar",
    "Height in pixels" : "Höjd i pixlar",
    "Toggle ratio lock" : "Växla låst bildförhållande",
    "Reset to original image size" : "Återställ till originalbildstorlek",
    "Rotate" : "Rotera",
    "Text" : "Text",
    "Text spacing" : "Textavstånd",
    "Text alignment" : "Textjustering",
    "Font family" : "Typsnittsfamilj",
    "Size" : "Storlek",
    "Letter spacing" : "Teckenavstånd",
    "Line height" : "Radavstånd",
    "Warmth" : "Värme",
    "+ Add watermark" : "+ Lägg till vattenstämpel",
    "+ Add text watermark" : "+ Lägg till vattenstämpel text",
    "Choose watermark type" : "Välj typ av vattenstämpel",
    "Upload watermark" : "Ladda upp vattenstämpel",
    "Add as text" : "Lägg till som text",
    "Padding" : "Utfyllnad",
    "Paddings" : "Utfyllnader",
    "Shadow" : "Skugga",
    "Horizontal" : "Horisontell",
    "Vertical" : "Vertikal",
    "Opacity" : "Opacitet",
    "Transparency" : "Transparens",
    "Position" : "Position",
    "Stroke" : "Penseldrag",
    "Save image as" : "Spara bild som",
    "Extension" : "Tillägg",
    "Format" : "Format",
    "Name is required." : "Namn är obligatoriskt.",
    "Quality" : "Kvalitet",
    "Saved image size (width x height)" : "Sparad bildstorlek (bredd x höjd)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Observera att det valda beskärningsområdet är lägre än den tillämpade storleksändringen, vilket kan orsaka kvalitetsförsämring",
    "Actual size (100%)" : "Faktisk storlek (100 %)",
    "Fit size" : "Passande storlek",
    "Select image to add …" : "Välj bild att lägga till ...",
    "Failed to load image." : "Det gick inte att ladda bilden.",
    "Menu" : "Meny",
    "Width" : "Bredd",
    "Height" : "Höjd",
    "No preview available for this crop item" : "Ingen förhandsgranskning tillgänglig för detta beskärningsobjekt"
},
"nplurals=2; plural=(n != 1);");
